pub struct SqliteEffectReplayOptions {
pub lease_timings: LeaseTimings,
}Expand description
Options for SQLite-backed runtime effect replay.
Fields
lease_timings: LeaseTimingsEffect-replay lease timing capability. Hosts share the same
LeaseTimings they configure on the runtime so effect leases expire
on the same failover window as session and process leases.